# Changelog

All notable changes to this project will be documented in this file.

## [1.0.0] - 2025-06-02
### Added
- Initial release
- PDF downloading
- DOI validation
- API handling
- Reporting
- Cross platform support
- Example scripts
